@@ -6,7 +6,11 @@ import requests
 import sys
 
 from audl.stats.endpoints._base import Endpoint
-#  from audl.stats.library.parameters import FileName
+
+#  old: https://audl-stat-server.herokuapp.com/web-api/player-stats?limit=20&year=2019&per=possessions&team=aviators
+#  old: https://theaudl.com/stats/player-stats?page=2&per=possessions&team=aviators&year=2019
+
+#  new: https://www.backend.audlstats.com/web-api/player-stats?limit=20
 
 
 class PlayerStats(Endpoint):
@@ -23,9 +27,6 @@ class PlayerStats(Endpoint):
             choices: ['all', 'aviators', ..., '<ext_team_id>']
     """
 
-#  https://audl-stat-server.herokuapp.com/web-api/player-stats?limit=20&year=2019&per=possessions&team=aviators
-#  https://theaudl.com/stats/player-stats?page=2&per=possessions&team=aviators&year=2019
-
     def __init__(self, season, per, team):
         """ 
         Parameters
@@ -47,7 +48,10 @@ class PlayerStats(Endpoint):
         self.season = season
         self.per = per
         self.team = team
-        super().__init__('https://audl-stat-server.herokuapp.com/web-api/player-stats?limit=20')
+        #  super().__init__('https://audl-stat-server.herokuapp.com/web-api/player-stats?limit=20')
+        super().__init__('https://www.backend.audlstats.com/web-api/player-stats?limit=20')
+
+
 
     def fetch_table(self, show_message=False):
         """
@@ -102,7 +106,7 @@ class PlayerStats(Endpoint):
         Examples
         --------
         >>> PlayerStats(2019, 'possessions', 'aviators')._get_url(3)
-        >>> https://theaudl.com/stats/player-stats?page=3&per=possessions&team=aviators&year=2019
+        >>> https://www.backend.audlstats.com/stats/player-stats?page=3&per=possessions&team=aviators&year=2019
 
 
         """
@@ -149,7 +153,6 @@ class PlayerStats(Endpoint):
         return players
 
 
-    # TODO: create Download class
     def download_stats_as_dataframe(self, file_path_name, show_message=True):
         """ 
         Function that download players stats as csv file
@@ -181,4 +184,12 @@ class PlayerStats(Endpoint):
             print('An error has occured when saving the file as csv')
         return flag 
 
+#  -----------------------------------------------------------------------------
 
+def main():
+    stats = PlayerStats(2022, 'game', 'aviators')
+    print(stats.fetch_table())
+    
+
+if __name__ == "__main__":
+    main()
